import { Component } from '@angular/core';
import {DatePipe, NgForOf, NgIf} from "@angular/common";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {
  NzTableComponent, NzTableModule,
  NzThMeasureDirective
} from "ng-zorro-antd/table";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzDividerComponent} from "ng-zorro-antd/divider";
import {NzDropDownADirective, NzDropDownDirective, NzDropdownMenuComponent} from "ng-zorro-antd/dropdown";
import {NzFormControlComponent, NzFormDirective, NzFormItemComponent, NzFormLabelComponent} from "ng-zorro-antd/form";
import {NzIconDirective} from "ng-zorro-antd/icon";

import {
    NzInputNumberComponent,
    NzInputNumberGroupComponent,
} from "ng-zorro-antd/input-number";
import {NzMenuDirective, NzMenuItemComponent} from "ng-zorro-antd/menu";
import {NzModalComponent, NzModalContentDirective, NzModalModule} from "ng-zorro-antd/modal";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {NzPopconfirmDirective} from "ng-zorro-antd/popconfirm";
import {FormGroup, NonNullableFormBuilder, ReactiveFormsModule, Validators} from "@angular/forms";

import {NzMessageService} from "ng-zorro-antd/message";
import {CommonService} from "../../../../services/common/common.service";
import {RechargeService} from "../../../../services/recharge/recharge.service";
import {NzInputDirective} from "ng-zorro-antd/input";
import {PriceTypePipe} from "../../../../pipes/recharge/price-type.pipe";

@Component({
  selector: 'app-price-list',
  standalone: true,
  imports: [
    NzModalComponent,
    NzFormLabelComponent,
    NzRowDirective,
    NzFormDirective,
    ReactiveFormsModule,
    NzColDirective,
    NzSelectComponent,
    NzOptionComponent,
    NzButtonComponent,
    NzTableComponent,
    NzThMeasureDirective,
    NgForOf,
    NzModalModule,
    NzDividerComponent,
    NzTableModule,
    NzDropDownADirective,
    DatePipe,
    NzDropDownDirective,
    NzDropdownMenuComponent,
    NzIconDirective,
    NzPopconfirmDirective,
    NzMenuDirective,
    NzMenuItemComponent,
    NzModalContentDirective,
    NzInputNumberGroupComponent,
    NzInputNumberComponent,
    NzFormControlComponent,
    NzFormItemComponent,
    NzInputDirective,
    PriceTypePipe

  ],
  templateUrl: './price-list.component.html',
  styleUrl: './price-list.component.less'
})
export class PriceListComponent {
  // 表单页数
  tablePageNum = 1;
  // 表单数据
  tableData: any = {
    total: 0,
    loading: false,
    list: [],
  };
  // 搜索表单
  searchForm: FormGroup;

  // 编辑产品类型表单
  editForm: FormGroup;
  // 编辑弹出框
  isVisibleEdit = false;


  constructor(private fb: NonNullableFormBuilder,
              private msg: NzMessageService,
              private commonService: CommonService,
              private rechargeService: RechargeService) {

    // 初始化搜索框
    this.searchForm = this.fb.group({
      type: [''],
    });

    // 初始化
    this.editForm = this.fb.group({
      type: ['' , [Validators.required]],
      sort: ['' , [Validators.required]],
      price: ['' , [Validators.required]],
      payPrice: ['' , [Validators.required]],
      id: [null],
    });
    this.getRequest();

  }

  // 查询列表
  public getRequest(reset: boolean = false) {
    this.tableData.loading  = true;
    if (reset) {
      this.tablePageNum = 1;
    }
    this.searchForm.value.pageNum = this.tablePageNum;
    this.searchForm.value.pageSize = 10;
    this.searchForm.value.time = new Date().getTime();

    this.rechargeService.getList(this.searchForm.value , (data: any) => {
      if (data['return_code'] == '000000') {
        this.tableData = data['return_data'];
      } else {
        this.msg.error(data['return_msg']);
      }
      this.tableData.loading  = false;
    });
  }


  // 唤醒编辑表单
  showEdit(item?: any) {
    if (item != null) {
      item.type = String(item.type);
      this.editForm.patchValue(item);
    } else {
      this.editForm.reset();
    }
    this.isVisibleEdit = true;
  }
  // 编辑表单提交
  handleEdit(): void {
    if (this.editForm.valid) {

      this.rechargeService.editPrice(this.editForm.value , (data: any) => {
        if (data['return_code'] === '000000') {
          this.msg.success("成功！");
          this.isVisibleEdit = false;
          this.getRequest();
        } else {
          this.msg.error(data['return_msg']);
        }
      });
    } else {
      Object.values(this.editForm.controls).forEach(control => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
    }

  }


  // 删除
  delete(id: number): void {
    this.rechargeService.delete(id , (data: any) => {
      if (data['return_code'] === '000000') {
        this.msg.success("成功！");
        this.getRequest();
      } else {
        this.msg.error(data['return_msg']);
      }
    });
  }


}
