import { Component } from '@angular/core';
import {NgForOf, NgIf} from "@angular/common";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzDatePickerComponent, NzRangePickerComponent} from "ng-zorro-antd/date-picker";
import {NzFormControlComponent, NzFormDirective, NzFormItemComponent, NzFormLabelComponent} from "ng-zorro-antd/form";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {
  NzTableCellDirective,
  NzTableComponent, NzTableModule,
  NzTbodyComponent,
  NzTheadComponent,
  NzThMeasureDirective, NzTrDirective
} from "ng-zorro-antd/table";
import {FormGroup, NonNullableFormBuilder, ReactiveFormsModule} from "@angular/forms";
import {DATA} from "../../../data/login/localStorage.namespace";
import {NzMessageService} from "ng-zorro-antd/message";
import {MerService} from "../../../services/merchant/mer.service";
import {CommunicationService} from "../../../services/common/communication.service";
import {SettlementService} from "../../../services/settlement/settlement.service";
import {BrowserStorageService} from "../../../utils/localStorage.service";
import {DateUtils} from "../../../utils/dateUtils.service";
import {orderPayType, platformCode} from "../../../data/goods/goods.namespace";

@Component({
  selector: 'app-list',
  standalone: true,
    imports: [
        NgForOf,
        NgIf,
        NzButtonComponent,
        NzColDirective,
        NzDatePickerComponent,
        NzFormControlComponent,
        NzFormDirective,
        NzFormItemComponent,
        NzFormLabelComponent,
        NzOptionComponent,
        NzRangePickerComponent,
        NzRowDirective,
        NzTableModule,
        NzSelectComponent,
        NzTableCellDirective,
        NzTableComponent,
        NzTbodyComponent,
        NzThMeasureDirective,
        NzTheadComponent,
        NzTrDirective,
        ReactiveFormsModule
    ],
  templateUrl: './list.component.html',
  styleUrl: './list.component.less'
})
export class ListComponent {
  protected readonly orderPayType = orderPayType;
  protected readonly platformCode = platformCode;
  // 表单页数
  tablePageNum = 1;
  // 表单数据
  tableData: any = {
    total: 0,
    loading: false,
    list: [],
  };
  // 搜索表单
  searchForm: FormGroup;
  merData: any;
  objectType: any;
  platform = this.storage.get(DATA)['account']['platformCode'];
  constructor(private fb: NonNullableFormBuilder,
              private msg: NzMessageService,
              private merService: MerService,
              private communicationService: CommunicationService,
              private settlement: SettlementService,
              private storage: BrowserStorageService,) {
    // 初始化搜索框
    this.searchForm = this.fb.group({
      platform: [''],
      merId: [''],
      finishTimeArray: [[]],
      finishTimeS: [''],
      finishTimeE: [''],
      payType: [''],
    });
    let timeObj = DateUtils.getDate(new Date(), Number(5));
    this.searchForm.controls['finishTimeArray'].setValue([timeObj.timeS, timeObj.timeE]);
    this.objectType =  this.storage.get(DATA)['account']['objectType'];
    this.getRequest();
    this.merList();
  }

  // 查询商户
  public merList() {
    let params: any = {
      pageNum: 1,
      pageSize: 1000,
      time: new Date().getTime(),
    }
    this.merService.queryList(params, (data: any) => {
      if (data['return_code'] == '000000') {
        this.merData = data['return_data']['list'];
      }
    });
  }

  // 查询列表
  public getRequest(reset: boolean = false) {

    if (this.searchForm.controls['finishTimeArray'].value != null
      && this.searchForm.controls['finishTimeArray'].value.length > 0) {
      this.searchForm.controls['finishTimeS'].setValue(DateUtils.getDateHMS(new Date(this.searchForm.controls['finishTimeArray'].value[0]) , 1).getTime());
      this.searchForm.controls['finishTimeE'].setValue(DateUtils.getDateHMS(new Date(this.searchForm.controls['finishTimeArray'].value[1]) , 2).getTime());
    } else {
      this.searchForm.controls['finishTimeS'].setValue(null)
      this.searchForm.controls['finishTimeE'].setValue(null)
    }

    if (this.platform != null) {
      this.searchForm.controls['platform'].setValue(this.platform)
    }

    this.tableData.loading  = true;
    if (reset) {
      this.tablePageNum = 1;
    }
    this.searchForm.value.time = new Date().getTime();

    this.settlement.getSettlement(this.searchForm.value , (data: any) => {
      if (data['return_code'] == '000000') {
        this.tableData.list = data['return_data'];
      } else {
        this.msg.error(data['return_msg']);
      }
      this.tableData.loading  = false;
    });
  }

  // 重制
  public reset() {
    this.searchForm.reset();
    this.getRequest();
  }

  // 订单导出
  public getExport() {
    this.searchForm.value.time = new Date().getTime();
    this.settlement.exportSettlement(this.searchForm.value , (data: any) => {
      if (data['return_code'] == '000000') {
        this.communicationService.sendMessage(data['return_data']);
      } else {
        this.msg.error(data['return_msg']);
      }
      this.tableData.loading  = false;
    });
  }

}

