
import {
  fallbackImg,
  logisticsStatus,
  orderCinemaStatus,
  orderGoodsChild,
  orderPayType
} from '../../../data/goods/goods.namespace';
import {NzTabSetComponent, NzTabsModule} from "ng-zorro-antd/tabs";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzFormDirective, NzFormModule} from "ng-zorro-antd/form";
import {FormGroup, FormsModule, NonNullableFormBuilder, ReactiveFormsModule} from "@angular/forms";
import {NzTreeSelectComponent} from "ng-zorro-antd/tree-select";
import {NzInputDirective} from "ng-zorro-antd/input";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {NzTableComponent, NzTableModule, NzThMeasureDirective} from "ng-zorro-antd/table";
import {NzImageDirective, NzImageModule} from "ng-zorro-antd/image";
import {NzModalModule} from "ng-zorro-antd/modal";
import {DatePipe, NgClass, NgForOf, NgIf} from "@angular/common";
import {NzDropDownADirective, NzDropDownDirective, NzDropdownMenuComponent} from "ng-zorro-antd/dropdown";
import {NzMenuDirective, NzMenuItemComponent} from "ng-zorro-antd/menu";
import {NzDescriptionsModule} from "ng-zorro-antd/descriptions";
import {NzPopconfirmDirective} from "ng-zorro-antd/popconfirm";
import {NzDividerComponent} from "ng-zorro-antd/divider";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {NzBadgeComponent} from "ng-zorro-antd/badge";
import {NzSpinComponent} from "ng-zorro-antd/spin";
import {NzTimelineComponent, NzTimelineItemComponent} from "ng-zorro-antd/timeline";
import {NzResultComponent} from "ng-zorro-antd/result";
import {NzDatePickerComponent, NzRangePickerComponent} from "ng-zorro-antd/date-picker";
import {NzRadioButtonDirective, NzRadioComponent, NzRadioGroupComponent} from "ng-zorro-antd/radio";
import {Component} from "@angular/core";
import {PayTypePipe} from "../../../pipes/goods/pay-type.pipe";
import {OrderChildStatusPipe} from "../../../pipes/goods/order-child-status.pipe";
import {NzMessageService} from "ng-zorro-antd/message";
import {BrowserStorageService} from "../../../utils/localStorage.service";
import {MerService} from "../../../services/merchant/mer.service";
import {IconService} from "../../../services/common/icon.service";
import {MeituanService} from "../../../services/trade/meituan.service";
import {DateUtils} from "../../../utils/dateUtils.service";
import {CommunicationService} from "../../../services/common/communication.service";
import {OrderCinemaStatusPipe} from "../../../pipes/goods/order-cinema-status.pipe";
import {OrderGoodsData} from "../../../model/order.interface";
import {MemberService} from "../../../services/trade/member.service";
@Component({
  selector: 'app-meituan-list',
  standalone: true,
  imports: [
    NzColDirective,
    NzRowDirective,
    NzFormDirective,
    ReactiveFormsModule,
    NzTreeSelectComponent,
    NzInputDirective,
    NzSelectComponent,
    NzOptionComponent,
    NzButtonComponent,
    NzTableComponent,
    NzImageModule,
    NzModalModule,
    NzTableModule,
    NzFormModule,
    NzThMeasureDirective,
    NgForOf,
    NzImageDirective,
    DatePipe,
    NzDropdownMenuComponent,
    NgIf,
    NzMenuDirective,
    NzDescriptionsModule,
    NzMenuItemComponent,
    NzPopconfirmDirective,
    NzDividerComponent,
    NzDropDownADirective,
    NzDropDownDirective,
    NzTabsModule,
    NzIconDirective,
    NzBadgeComponent,
    NzTabSetComponent,
    FormsModule,
    NzSpinComponent,
    NzTimelineItemComponent,
    NgClass,
    NzResultComponent,
    NzTimelineComponent,
    NzDatePickerComponent,
    NzRadioButtonDirective,
    NzRadioComponent,
    NzRadioGroupComponent,
    NzRangePickerComponent,
    PayTypePipe,
    OrderChildStatusPipe,
    OrderCinemaStatusPipe,
  ],
  templateUrl: './member-list.component.html',
  styleUrl: './member-list.component.less'
})
export class MemberListComponent {
  // 表单页数
  tablePageNum = 1;
  // 表单数据
  tableData: any = {
    total: 0,
    loading: false,
    list: [],
  };
  // 搜索表单
  searchForm: FormGroup;
  orderDetailModal = false;
  // 更多查询条件
  isCollapse = false;
  orderGoodsData: any;

  protected readonly orderGoodsChild = orderGoodsChild;
  protected readonly orderPayType = orderPayType;

  constructor(private fb: NonNullableFormBuilder,
              private msg: NzMessageService,
              private iconService: IconService,
              private communicationService: CommunicationService,
              private memberService: MemberService,) {




    // 初始化搜索框
    this.searchForm = this.fb.group({
      orderNo: [''],
      childOrderNo: [''],
      userPhone: [''],
      createTimeArray: [[]],
      finishTimeArray: [[]],
      createTimeS: [''],
      createTimeE: [''],
      finishTimeS: [''],
      finishTimeE: [''],
      goodsName: [''],
      status: [''],
      payType: [''],
    });
    this.getRequest();
  }


  // 查询列表
  public getRequest(reset: boolean = false) {

    if (this.searchForm.controls['createTimeArray'].value != null
      && this.searchForm.controls['createTimeArray'].value.length > 0) {
      this.searchForm.controls['createTimeS'].setValue(DateUtils.getDateHMS(new Date(this.searchForm.controls['createTimeArray'].value[0]) , 1).getTime());
      this.searchForm.controls['createTimeE'].setValue(DateUtils.getDateHMS(new Date(this.searchForm.controls['createTimeArray'].value[1]) , 2).getTime());
    } else {
      this.searchForm.controls['createTimeS'].setValue(null)
      this.searchForm.controls['createTimeE'].setValue(null)
    }
    if (this.searchForm.controls['finishTimeArray'].value != null
      && this.searchForm.controls['finishTimeArray'].value.length > 0) {
      this.searchForm.controls['finishTimeS'].setValue(DateUtils.getDateHMS(new Date(this.searchForm.controls['finishTimeArray'].value[0]) , 1).getTime());
      this.searchForm.controls['finishTimeE'].setValue(DateUtils.getDateHMS(new Date(this.searchForm.controls['finishTimeArray'].value[1]) , 2).getTime());
    } else {
      this.searchForm.controls['finishTimeS'].setValue(null)
      this.searchForm.controls['finishTimeE'].setValue(null)
    }

    this.tableData.loading  = true;
    if (reset) {
      this.tablePageNum = 1;
    }
    this.searchForm.value.pageNum = this.tablePageNum;
    this.searchForm.value.pageSize = 10;
    this.searchForm.value.time = new Date().getTime();

    this.memberService.getListMember(this.searchForm.value , (data: any) => {
      if (data['return_code'] == '000000') {
        this.tableData = data['return_data'];
      } else {
        this.msg.error(data['return_msg']);
      }
      this.tableData.loading  = false;
    });
  }

  // 重制
  public reset() {
    this.searchForm.reset();
    this.getRequest();
  }



  showDetail(data: OrderGoodsData): void {
    this.orderGoodsData = data;
    this.orderDetailModal  = true;
  }
}
