import { Component } from '@angular/core';
import {FormGroup, NonNullableFormBuilder, ReactiveFormsModule} from "@angular/forms";
import {NzMessageService} from "ng-zorro-antd/message";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzFormControlComponent, NzFormDirective, NzFormLabelComponent, NzFormModule} from "ng-zorro-antd/form";
import {NzInputDirective} from "ng-zorro-antd/input";
import {NzDatePickerComponent, NzRangePickerComponent} from "ng-zorro-antd/date-picker";
import {NzRadioButtonDirective, NzRadioComponent, NzRadioGroupComponent} from "ng-zorro-antd/radio";
import {DatePipe, NgClass, NgForOf, NgIf, NgOptimizedImage} from "@angular/common";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {NzCellFixedDirective, NzTableComponent, NzTableModule, NzThMeasureDirective} from "ng-zorro-antd/table";
import {NzModalComponent, NzModalContentDirective, NzModalModule} from "ng-zorro-antd/modal";
import {NzTabComponent, NzTabSetComponent} from "ng-zorro-antd/tabs";
import {NzDescriptionsComponent, NzDescriptionsItemComponent} from "ng-zorro-antd/descriptions";
import {NzImageDirective, NzImageGroupComponent, NzImageModule} from "ng-zorro-antd/image";
import {OrderStarbucksService} from "../../../services/trade/order-starbucks.service";
import {OrderStarbucksPipe} from "../../../pipes/goods/order-starbucks.pipe";
import {
  fallbackImg,
  orderGoodsChild,
  orderPayType,
} from "../../../data/goods/goods.namespace";
import {DateUtils} from "../../../utils/dateUtils.service";
import {OrderChildStatusPipe} from "../../../pipes/goods/order-child-status.pipe";
import {OrderService} from "../../../services/trade/order.service";
import {OrderCinemaStatusPipe} from "../../../pipes/goods/order-cinema-status.pipe";
import {PayTypePipe} from "../../../pipes/goods/pay-type.pipe";
import {NzIconDirective, NzIconService} from "ng-zorro-antd/icon";
import {IconService} from "../../../services/common/icon.service";
import {NzBadgeComponent} from "ng-zorro-antd/badge";
import {OrderStarbucksTypePipe} from "../../../pipes/goods/order-starbucks-type.pipe";

@Component({
  selector: 'app-order-starbucks',
  standalone: true,
  imports: [
    ReactiveFormsModule,
    NzRowDirective,
    NzFormLabelComponent,
    NzFormControlComponent,
    NzColDirective,
    NzInputDirective,
    NzDatePickerComponent,
    NzRadioGroupComponent,
    NzRadioButtonDirective,
    NzTableModule,
    NzModalModule,
    NzFormModule,
    NgForOf,
    NzRadioComponent,
    NzSelectComponent,
    NzButtonComponent,
    NzTableComponent,
    NzThMeasureDirective,
    NzCellFixedDirective,
    NgClass,
    DatePipe,
    NzModalComponent,
    NzTabSetComponent,
    NzDescriptionsComponent,
    NzTabComponent,
    NzDescriptionsItemComponent,
    NzImageGroupComponent,
    NzImageDirective,
    NzFormDirective,
    NzImageModule,
    NzModalContentDirective,
    OrderStarbucksPipe,
    NzOptionComponent,
    NzRangePickerComponent,
    OrderChildStatusPipe,
    NgIf,
    OrderCinemaStatusPipe,
    PayTypePipe,
    NgOptimizedImage,
    NzIconDirective,
    NzBadgeComponent,
    OrderStarbucksTypePipe
  ],
  templateUrl: './order-starbucks.component.html',
  styleUrl: './order-starbucks.component.less'
})
export class OrderStarbucksComponent {
  // 表单页数
  tablePageNum = 1;
  // 表单数据
  tableData: any = {
    total: 0,
    loading: false,
    list: [],
  };
  // 搜索表单
  searchForm: FormGroup;
  orderDetailModal = false;
  orderGoodsData: any;
  orderChild: any;

  protected readonly orderGoodsChild = orderGoodsChild;
  protected readonly orderPayType = orderPayType;

  constructor(private fb: NonNullableFormBuilder,
              private msg: NzMessageService,
              private iconService: IconService,
              private orderService: OrderService,
              private orderStarbucks: OrderStarbucksService) {

    // 初始化搜索框
    this.searchForm = this.fb.group({
      orderNo: [''],
      childOrderNo: [''],
      userPhone: [''],
      productName: [''],
      storeName: [''],
      storeAddress: [''],
      createTimeArray: [[]],
      createTimeS: [''],
      createTimeE: [''],
      goodsName: [''],
      payType: [''],
      status: [''],
    });
    this.getRequest();
  }

  // 查询列表
  public getRequest(reset: boolean = false) {

    if (this.searchForm.controls['createTimeArray'].value != null
      && this.searchForm.controls['createTimeArray'].value.length > 0) {
      this.searchForm.controls['createTimeS'].setValue(DateUtils.getDateHMS(new Date(this.searchForm.controls['createTimeArray'].value[0]) , 1).getTime());
      this.searchForm.controls['createTimeE'].setValue(DateUtils.getDateHMS(new Date(this.searchForm.controls['createTimeArray'].value[1]) , 2).getTime());
    } else {
      this.searchForm.controls['createTimeS'].setValue(null)
      this.searchForm.controls['createTimeE'].setValue(null)
    }

    this.tableData.loading  = true;
    if (reset) {
      this.tablePageNum = 1;
    }
    this.searchForm.value.pageNum = this.tablePageNum;
    this.searchForm.value.pageSize = 10;
    this.searchForm.value.time = new Date().getTime();

    this.orderStarbucks.getListStarbucks(this.searchForm.value , (data: any) => {
      if (data['return_code'] == '000000') {
        this.tableData = data['return_data'];
      } else {
        this.msg.error(data['return_msg']);
      }
      this.tableData.loading  = false;
    });
  }

  // 重制
  public reset() {
    this.searchForm.reset();
    this.getRequest();
  }

  // 查询详情
  showDetail(orderNo: string): void {
    this.orderService.queryOrder(orderNo , (data: any) => {
      if (data['return_code'] == '000000') {
        this.orderGoodsData = data['return_data'];
        this.orderChild = this.orderGoodsData['orderChildList'][0]
      } else {
        this.msg.error(data['return_msg']);
      }
    })
    this.orderDetailModal  = true;
  }


  protected readonly fallbackImg = fallbackImg;
}
